==> apache-drill-1.19.0-src.tar.gz: apache-drill-1.19.0-src/exec/java-exec/src/main/java/org/apache/drill/exec/store/security/UsernamePasswordCredentials.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.store.security;

import org.apache.drill.common.logical.security.CredentialsProvider;

import java.util.Map;

public class UsernamePasswordCredentials {
  public static final String USERNAME = "username";
  public static final String PASSWORD = "password";

  private final String username;
  private final String password;

  public UsernamePasswordCredentials(CredentialsProvider credentialsProvider) {
    Map<String, String> credentials = credentialsProvider.getCredentials();
    this.username = credentials.get(USERNAME);
    this.password = credentials.get(PASSWORD);
  }

  public String getUsername() {
    return username;
  }

  public String getPassword() {
    return password;
  }
}

==> apache-drill-1.20.1-src.tar.gz: apache-drill-1.20.1-src/exec/java-exec/src/main/java/org/apache/drill/exec/store/security/UsernamePasswordCredentials.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.store.security;

import org.apache.drill.common.logical.security.CredentialsProvider;

import java.util.HashMap;
import java.util.Map;

public class UsernamePasswordCredentials {
  public static final String USERNAME = "username";
  public static final String PASSWORD = "password";

  private final String username;
  private final String password;

  public UsernamePasswordCredentials(CredentialsProvider credentialsProvider) {
    if (credentialsProvider == null) {
      this.username = null;
      this.password = null;
    } else {
      Map<String, String> credentials = credentialsProvider.getCredentials() == null ? new HashMap<>() : credentialsProvider.getCredentials();
      this.username = credentials.get(USERNAME);
      this.password = credentials.get(PASSWORD);
    }
  }

  public String getUsername() {
    return username;
  }

  public String getPassword() {
    return password;
  }
}
